package de.intevation.flys.model;

import java.io.Serializable;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.persistence.GeneratedValue;
import javax.persistence.Column;
import javax.persistence.SequenceGenerator;
import javax.persistence.GenerationType;
import javax.persistence.OneToMany;
import javax.persistence.OneToOne;
import javax.persistence.JoinColumn;

import java.util.List;

@Entity
@Table(name = "discharge_tables")
public class DischargeTable
implements   Serializable
{
    private Integer      id;
    private Gauge        gauge;
    private String       description;
    private Integer      kind;
    private TimeInterval timeInterval;

    private List<DischargeTableValue> dischargeTableValues;

    public DischargeTable() {
        kind = 0;
    }

    public DischargeTable(Gauge gauge) {
        this(gauge, null, 0, null);
    }

    public DischargeTable(
        Gauge        gauge,
        String       description,
        Integer      kind,
        TimeInterval timeInterval
    ) {
        this.gauge        = gauge;
        this.description  = description;
        this.kind         = kind;
        this.timeInterval = timeInterval;
    }

    @Id
    @SequenceGenerator(
        name           = "SEQUENCE_DISCHARGE_TABLES_ID_SEQ",
        sequenceName   = "DISCHARGE_TABLES_ID_SEQ",
        allocationSize = 1)
    @GeneratedValue(
        strategy  = GenerationType.SEQUENCE,
        generator = "SEQUENCE_DISCHARGE_TABLES_ID_SEQ")
    @Column(name = "id")
    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    @OneToOne
    @JoinColumn(name = "gauge_id" )
    public Gauge getGauge() {
        return gauge;
    }

    public void setGauge(Gauge gauge) {
        this.gauge = gauge;
    }

    @Column(name = "description")
    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    @Column(name = "kind")
    public Integer getKind() {
        return kind;
    }

    public void setKind(Integer kind) {
        this.kind = kind;
    }

    @OneToOne
    @JoinColumn(name = "time_interval_id" )
    public TimeInterval getTimeInterval() {
        return timeInterval;
    }

    public void setTimeInterval(TimeInterval timeInterval) {
        this.timeInterval = timeInterval;
    }

    @OneToMany
    @JoinColumn(name = "table_id")
    public List<DischargeTableValue> getDischargeTableValues() {
        return dischargeTableValues;
    }

    public void setDischargeTableValues(
        List<DischargeTableValue> dischargeTableValues
    ) {
        this.dischargeTableValues = dischargeTableValues;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
